pub fn chunk_size_events() -> usizeExpand description
Returns the configured source sender chunk size in events, or DEFAULT_CHUNK_SIZE_EVENTS if
unset.
pub fn chunk_size_events() -> usizeReturns the configured source sender chunk size in events, or DEFAULT_CHUNK_SIZE_EVENTS if
unset.